@@ -183,7 +183,7 @@ class Server(object):
             >>> from couchdbkit import Server
             >>> from restkit.httpc import BasicAuth
             >>> server = Server()
-            >>> server.add_authorization(BasicAuth((username, password)))
+            >>> server.add_authorization(BasicAuth(username, password))
         """
         self.res.add_authorization(obj_auth)
           
@@ -273,11 +273,23 @@ class Database(object):
         return res.json_body
 
     def flush(self):
-        _design_docs = [self[i["id"]] for i in self.all_docs(startkey="_design", endkey="_design/"+u"\u9999")]
+        """ Remove all docs from a database
+        except design docs."""
+        # save ddocs
+        all_ddocs = self.all_docs(startkey="_design", 
+                            endkey="_design/"+u"\u9999",
+                            include_docs=True)
+        ddocs = []
+        for ddoc in all_ddocs:
+            ddoc['doc'].pop('_rev')
+            ddocs.append(ddoc['doc'])
+        
+        # delete db
         self.server.delete_db(self.dbname)
+        
+        # recreate db + ddocs
         self.server.create_db(self.dbname)
-        [i.pop("_rev") for i in _design_docs]
-        self.bulk_save( _design_docs )
+        self.bulk_save(ddocs)
         
     def doc_exist(self, docid):
         """Test if document exists in a database
@@ -380,7 +392,7 @@ class Database(object):
                                     raw=_raw_json)
         except resource.ResourceNotFound:
             return None
-        return doc_with_revs           
+        return doc_with_revs
         
     def save_doc(self, doc, encode_attachments=True, _raw_json=False, **params):
         """ Save a document. It will use the `_id` member of the document 
@@ -397,6 +409,8 @@ class Database(object):
         
         with `_raw_json=True` It return raw response. If False it update 
         doc instance with new revision (if batch=False).
+        
+        @return res: result of save. doc is updated in the mean time
         """
         if doc is None:
             doc = {}
@@ -415,13 +429,15 @@ class Database(object):
             except:
                 res = maybe_raw(self.res.post(payload=doc, **params), raw=_raw_json)
                 
-        if _raw_json:    
+        if _raw_json:
             return res
                 
         if 'batch' in params and 'id' in res:
             doc.update({ '_id': res['id']})
         else:
-            doc.update({ '_id': res['id'], '_rev': res['rev']})
+            doc.update({'_id': res['id'], '_rev': res['rev']})
+            
+        return res
         
     def bulk_save(self, docs, use_uuids=True, all_or_nothing=False, _raw_json=False):
         """ bulk save. Modify Multiple Documents With a Single Request
@@ -463,7 +479,7 @@ class Database(object):
                     
         payload = { "docs": docs }
         if all_or_nothing:
-            payload["all-or-nothing"] = True
+            payload["all_or_nothing"] = True
             
         # update docs
         results = maybe_raw(self.res.post('/_bulk_docs', payload=payload),
@@ -564,7 +580,7 @@ class Database(object):
         
     def view(self, view_name, obj=None, wrapper=None, **params):
         """ get view results from database. viewname is generally 
-        a string like `designname/viewnam". It return an ViewResults
+        a string like `designname/viewname". It return an ViewResults
         object on which you could iterate, list, ... . You could wrap
         results in wrapper function, a wrapper function take a row
         as argument. Wrapping could be also done by passing an Object 
@@ -659,7 +675,7 @@ class Database(object):
             if hasattr(content, "name"):
                 name = content.name
             else:
-                raise InvalidAttachment('You should provid a valid attachment name')
+                raise InvalidAttachment('You should provide a valid attachment name')
         name = url_quote(name, safe="")
         if content_type is None:
             content_type = ';'.join(filter(None, guess_type(name)))
@@ -909,7 +925,8 @@ class ViewInterface(object):
         raise NotImplementedError
         
 class View(ViewInterface):
-    """ Object used to wrap a view and return ViewResults. Generally called. """
+    """ Object used to wrap a view and return ViewResults. 
+    Generally called via the `view` method in a `Database` instance. """
     
     def __init__(self, db, view_path, wrapper=None):
         ViewInterface.__init__(self, db, wrapper=wrapper)
