@@ -16,6 +16,7 @@
 #
 __author__ = 'benoitc@e-engura.com (Benoît Chesneau)'
 
+import copy
 import unittest
 
 from couchdbkit import ResourceNotFound, RequestFailed
@@ -220,6 +221,8 @@ class ClientDatabaseTestCase(unittest.TestCase):
         self.assertFalse(db.doc_exist('test'))
         self.assertFalse(db.doc_exist('test2'))
         self.assert_(db.doc_exist('_design/test'))
+        ddoc = db.get("_design/test")
+        self.assert_('all' in ddoc['views'])
         del self.Server['couchdbkit_test']
     
     def testDbLen(self):
@@ -478,21 +481,39 @@ class ClientDatabaseTestCase(unittest.TestCase):
 
         self.assertRaises(BulkSaveError, db.bulk_save, docs1)
 
-        def errors():
-            docs2 = [
-                docs1[0],
-                docs1[1],
-                {'_id': docs[2]['_id'], 'string': 'test', 'number': 4 },
-                {'_id': docs[3]['_id'], 'string': 'test', 'number': 6 }
-            ]
-            try:
-                db.bulk_save(docs2)
-            except BulkSaveError, e:
-                return e.errors
-       
-
-        self.assert_(len(errors()) == 2)
+        docs2 = [
+            docs1[0],
+            docs1[1],
+            {'_id': docs[2]['_id'], 'string': 'test', 'number': 4 },
+            {'_id': docs[3]['_id'], 'string': 'test', 'number': 6 }
+        ]
+        doc23 = docs2[3].copy()
+        all_errors = []
+        try:
+            db.bulk_save(docs2)
+        except BulkSaveError, e:
+            all_errors = e.errors
 
+        self.assert_(len(all_errors) == 2)
+        self.assert_(all_errors[0]['error'] == 'conflict')
+        self.assert_(doc23 == docs2[3])
+        
+        docs3 = [
+            docs2[0],
+            docs2[1],
+            {'_id': docs[2]['_id'], 'string': 'test', 'number': 4 },
+            {'_id': docs[3]['_id'], 'string': 'test', 'number': 6 }
+        ]
+        
+        doc33 = docs3[3].copy()
+        all_errors2 = []
+        try:
+            db.bulk_save(docs3, all_or_nothing=True)
+        except BulkSaveError, e:
+            all_errors2 = e.errors
+        
+        self.assert_(len(all_errors2) == 0)
+        self.assert_(doc33 != docs3[3])
         del self.Server['couchdbkit_test']
 
 
